Name:		gromacs
Summary:	Molecular dynamics package (non-mpi version)
Version:	2025.2
Release:	%mkrel 1
License:	LGPLv2+
Group:		Sciences/Chemistry
URL:		https://www.gromacs.org/
Source0:	https://ftp.gromacs.org/gromacs/%{name}-%{version}.tar.gz
# 32-bit archs officially unsupported
# https://gitlab.com/gromacs/gromacs/-/merge_requests/2453
ExcludeArch:	%{ix86} %{arm}
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	imagemagick
BuildRequires:	python3dist(sphinx)
BuildRequires:	openblas-devel
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(hwloc)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(lmfit)
BuildRequires:	pkgconfig(muparser) >= 2.3.4

Requires:	fftw >= 3.0.1

%description
GROMACS is a versatile and extremely well optimized package
to perform molecular dynamics computer simulations and
subsequent trajectory analysis. It is developed for
biomolecules like proteins, but the extremely high
performance means it is used also in several other field
like polymer chemistry and solid state physics.

%package	devel
Summary:	Header files and static libraries for GROMACS
Group:		Development/C++
Requires:	%{name} = %{version}

%description devel
This package contains header files, static libraries,
and a program example for the GROMACS molecular
dynamics software. You need it if you want to write your
own analysis programs.

%prep
%autosetup

%build
%cmake -DGMX_HWLOC=ON \
       -DGMX_USE_LMFIT=EXTERNAL \
       -DGMX_USE_MUPARSER=EXTERNAL \
       -DGMX_BLAS_USER=openblas \
       -DGMX_LAPACK_USER=openblas
%cmake_build

%install
%cmake_install

%files
%doc AUTHORS README
%license COPYING
%{_bindir}/*
%{_mandir}/man*/*
%{_datadir}/%{name}/
%{_libdir}/*.so.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/cmake/gromacs/
%{_datadir}/cmake/gmxapi/


%changelog
* Sat May 24 2025 daviddavid <daviddavid> 2025.2-1.mga10
+ Revision: 2186223
- new version: 2025.2

* Fri Apr 11 2025 daviddavid <daviddavid> 2025.1-1.mga10
+ Revision: 2174601
- new version: 2025.1

* Thu Jan 30 2025 daviddavid <daviddavid> 2024.5-1.mga10
+ Revision: 2143479
- new version: 2024.5

* Tue Dec 03 2024 daviddavid <daviddavid> 2024.4-1.mga10
+ Revision: 2120744
- new version: 2024.4

* Sun Sep 15 2024 daviddavid <daviddavid> 2024.3-1.mga10
+ Revision: 2096747
- new version: 2024.3

* Fri Jun 07 2024 daviddavid <daviddavid> 2024.2-1.mga10
+ Revision: 2070432
- new version: 2024.2

* Tue Apr 23 2024 daviddavid <daviddavid> 2024.1-1.mga10
+ Revision: 2060663
- new version: 2024.1
- 32-bit archs officially unsupported

* Thu Feb 15 2024 daviddavid <daviddavid> 2024-1.mga10
+ Revision: 2041314
- new version: 2024

* Thu Nov 02 2023 daviddavid <daviddavid> 2023.3-1.mga10
+ Revision: 2003521
- new version: 2023.3

* Tue Sep 19 2023 daviddavid <daviddavid> 2023.2-1.mga10
+ Revision: 1988016
- new version: 2023.2

* Sat Feb 18 2023 daviddavid <daviddavid> 2023-1.mga9
+ Revision: 1943862
- new version: 2023
- use system openblas/lapack
- use system muparser and lmfit
- enable hwloc support

* Thu Mar 31 2022 umeabot <umeabot> 5.0.7-4.mga9
+ Revision: 1837538
- Mageia 9 Mass Rebuild

* Thu Feb 13 2020 umeabot <umeabot> 5.0.7-3.mga8
+ Revision: 1512705
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Sep 23 2018 umeabot <umeabot> 5.0.7-2.mga7
+ Revision: 1298081
- Mageia 7 Mass Rebuild

* Thu Mar 29 2018 kekepower <kekepower> 5.0.7-1.mga7
+ Revision: 1213277
- Update to version 5.0.7

* Tue Feb 02 2016 umeabot <umeabot> 4.6.6-4.mga6
+ Revision: 932570
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.6.6-3.mga5
+ Revision: 747979
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.6.6-2.mga5
+ Revision: 679947
- Mageia 5 Mass Rebuild

* Sun Aug 24 2014 akien <akien> 4.6.6-1.mga5
+ Revision: 667108
- Version 4.6.6

* Sat Oct 19 2013 umeabot <umeabot> 4.6.3-2.mga4
+ Revision: 529944
- Mageia 4 Mass Rebuild

* Sun Jul 14 2013 sander85 <sander85> 4.6.3-1.mga4
+ Revision: 454199
- New version: 4.6.3

* Sun Jun 02 2013 tv <tv> 4.6.2-2.mga4
+ Revision: 435231
- fix description

* Sun Jun 02 2013 sander85 <sander85> 4.6.2-1.mga4
+ Revision: 434440
- New version: 4.6.2

* Sat Jan 12 2013 umeabot <umeabot> 4.5.5-3.mga3
+ Revision: 352644
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 10 2011 eatdirt <eatdirt> 4.5.5-2.mga2
+ Revision: 180329
- (Re)built for fftw-3.3
  Added missing source file
  Fix wrong install lib path on x86_64
+ steletch <steletch>
- Update to 4.5.5
+ tv <tv>
- new release

* Mon Feb 07 2011 steletch <steletch> 4.5.3-2.mga1
+ Revision: 48837
- imported package gromacs


* Fri Feb 04 2011 Funda Wang <fwang@mandriva.org> 4.5.3-2mdv2011.0
+ Revision: 635894
- tighten BR
- install into correct libdir

* Tue Nov 16 2010 Stéphane Téletchéa <steletch@mandriva.org> 4.5.3-1mdv2011.0
+ Revision: 598092
- New version 4.5.3

* Thu Nov 11 2010 Stéphane Téletchéa <steletch@mandriva.org> 4.5.2-1mdv2011.0
+ Revision: 596299
- Workaround cmake build
- Fix installation path
- Fix man and library names
- Add missing buildroot
- Launch the installation from the cmake build subdir
- Missing BR
- Update to cmake system
- Update to 4.5.2
- Update to gromacs 4.5.1

* Mon Mar 15 2010 Stéphane Téletchéa <steletch@mandriva.org> 4.0.7-2mdv2011.0
+ Revision: 519886
- Fix libdir inclusion to avoid owning the directory which prevents removing the debug files

* Mon Dec 14 2009 Stéphane Téletchéa <steletch@mandriva.org> 4.0.7-1mdv2010.1
+ Revision: 478487
- Update to 4.0.7

* Mon Sep 28 2009 Stéphane Téletchéa <steletch@mandriva.org> 4.0.5-1mdv2010.0
+ Revision: 450710
- gromacs uses a libmd now
- Disco is no more present
- Update to 4.0.5
- Disable for now the underlinking check
- Add missing BR (and increase fftw requirement)

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 3.3.2-3mdv2009.0
+ Revision: 246640
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Oct 23 2007 Jérôme Soyer <saispo@mandriva.org> 3.3.2-1mdv2008.1
+ Revision: 101472
- New release
- import gromacs


* Tue Apr 11 2006 Lenny Cartier <lenny@mandriva.com> 3.3.1-1mdk
- 3.3.1

* Mon Nov 07 2005 Nicolas Lécureuil <neoclust@mandriva.org> 3.3-2mdk
- Fix BuildRequires

* Thu Oct 20 2005 Lenny Cartier <lenny@mandriva.com> 3.3-1mdk
- 3.3

* Fri Jun 04 2004 Lenny Cartier <lenny@mandrakesoft.com> 3.2.1-1mdk
- 3.2.1

* Wed Apr 30 2003 Lenny Cartier <lenny@mandrakesoft.com> 3.1.4-3mdk
- buildrequires

* Sun Feb 02 2003 Lenny Cartier <lenny@mandrakesoft.com> 3.1.4-2mdk
- rebuild

* Tue Dec 05 2002 Lenny Cartier <lenny@mandrakesoft.com> 3.1.4-1mdk 
- from Austin Acton <aacton@yorkul.ca> :
	- initial package for Mandrake 9.0+
